# eric7.PluginManager.PluginDetailsDialog

Module implementing the Plugin Details Dialog.

### Global Attributes

None

### Classes

PluginDetailsDialog | Class implementing the Plugin Details Dialog.

### Functions

None

## PluginDetailsDialog

Class implementing the Plugin Details Dialog.

### Derived from

QDialog, Ui_PluginDetailsDialog

### Class Attributes

None

### Class Methods

None

### Methods

PluginDetailsDialog | Constructor
on_activeCheckBox_clicked | Private slot called, when the activeCheckBox was clicked.
on_autoactivateCheckBox_clicked | Private slot called, when the autoactivateCheckBox was clicked.

### Static Methods

None

#### PluginDetailsDialog (Constructor)

PluginDetailsDialog(details, parent=None)

Constructor

details (dict)
  dictionary containing the info to be displayed
parent (QWidget)
  parent of this dialog

#### PluginDetailsDialog.on_activeCheckBox_clicked

on_activeCheckBox_clicked()

Private slot called, when the activeCheckBox was clicked.

#### PluginDetailsDialog.on_autoactivateCheckBox_clicked

on_autoactivateCheckBox_clicked()

Private slot called, when the autoactivateCheckBox was clicked.

Up